==> gnome-admin-0.26.tar.gz: gnome-admin-0.26/gxsnmp/app/snmp_host.h <==
/*
 * $Id: snmp_host.h,v 1.21 1998/08/12 00:54:01 gregm Exp $
 * GXSNMP -- An snmp management application
 * Copyright (C) 1998 Gregory McLean
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 * Variables and functions specific to the host panel
 */
#ifndef __SNMP_HOST_H__
#define __SNMP_HOST_H__

#include <sys/types.h>
#include <time.h>
#include <gtk/gtk.h>
#include <netdb.h>
#include <netinet/in.h>
#include "net.h"

/* 
 * For the add host dialog 
 */
typedef struct _host_panel {
  GtkWidget 	*window;	    /* the window */
  GtkWidget     *buttons[2];        /* The buttons */
  GtkWidget     *entries[8];        /* The text entry widgets */
  GtkWidget     *s_widgets[2];      /* Server page widgets */
} host_panel;

/*
 * Used for both the set and get panels.
 */
typedef struct _set_panel {
  GtkWidget     *window;
  GtkWidget     *entries[3];
  GtkWidget     *buttons[3];
} set_panel;

#define HOST_OK_BUTTON   0
#define HOST_CAN_BUTTON  1

#define HOST_E_NAME   0
#define HOST_E_DISP   1
#define HOST_E_PORT   2
#define HOST_E_RCOM   3
#define HOST_E_WCOM   4
#define HOST_E_VERS   5
#define HOST_E_RETR   6
#define HOST_E_TIME   7

#define HOST_S_POLL   0
#define HOST_S_SERV   1

#define SET_QUERY_BUTTON  0
#define SET_CLEAR_BUTTON  1
#define SET_CLOSE_BUTTON  2

#define SET_MIB_ENTRY     0
#define SET_MIB_HOST      1
#define SET_MIB_RESULT    2

typedef struct __edit_host {
  GtkWidget     *window;
  GtkWidget     *widget[8];
} edit_host;


/*
 * Defines for the following host list
 */
#define HOST_STATE_UNKNOWN   -1
#define HOST_STATE_UP        0x01
#define HOST_STATE_DOWN      0x02

/*
 * Simple map location cordinates.
 */
typedef struct _map_location {
  int           x;
  int           y;
  int           width;
  int           height;
} location;

typedef struct _inf_list {
  struct in_addr    if_addr;
  struct in_addr    if_net;
  struct in_addr    if_mask;
  u_long            if_lastsnmp;
  int               if_flags;
  struct _hosts     *if_host;   /* the host entry for this interface */
  int               if_speed;
  char              if_index;
  u_long            if_lastup;
} inf_list;

typedef struct _hosts {
  char          *hl_disp;       /* what we should display on the map */
  GSList        *hl_if;         /* Interface list for this host*/
  int           if_count;       /* counter for querying interfaces from this
				 * host */
  gulong        root[SNMP_SIZE_OBJECTID];
  int           root_length;
  gulong        name[SNMP_SIZE_OBJECTID];
  int           name_length;
  u_long        hl_lastpong;    /* last response from a ping */
  int           hl_flags;       /* Flags for this host */
  int           hl_state;       /* The state of this host UP/Down etc.. */
  host_snmp     hl_snmp;        /* the snmp info associated with this host */
  GList         *monitor_list;  /* A list of mibs to monitor for this host */
  GtkWidget     *widget;        /* the widget that displays this host */
  GtkWidget     *listwidget;    /* the widget on the host list for this host */
  GnomeCanvasGroup *hl_mgroup;	/* The group for this host on the map */
  GnomeCanvasGroup *hl_ngroup;  /* The network group that this is connected to */
  GnomeCanvasItem  *hl_mconnection; /* The connect to the network */
  net_entry     *hl_network;    /* network we are connected to */
  location      hl_location;    /* Where to put this host on the map */
  u_long        hl_lastsnmpif;
  time_t        hl_lastsnmp;
  int           snmp_running;   /* do we have a request running? */
  int           rowid;          /* SQL row ID */
} hosts;

#define DEFAULT_COMMUNITY	"public"           /* read */
#define DEFAULT_WCOMMUNITY      "private"          /* write */
#define DEFAULT_PORT		"161"
/* 1 - 300 range */
#define DEFAULT_TIMEOUT		"30"
/* 1 - 32 range */
#define DEFAULT_RETRIES		"3"

/*
 * SQL stuff
 */
#define DEFAULT_DATABASE        "gxsnmp"


/*
 * Global functions defined by this module
 */
void add_host                   (hosts *entry);
/*
 * Exported standard panel functions
 */
void               open_add_host_panel            (void);
void               hide_add_host_panel            (void);
void               destroy_add_host_panel         (void);
void               reset_add_host_panel           (void);

void               open_edit_panel                (void);
void               hide_edit_panel                (void);
void               destroy_edit_panel             (void);
void               reset_edit_panel               (void);

void               open_set_panel                 (void);
void               destroy_set_panel              (void);
void               hide_set_panel                 (void);
void               reset_set_panel                (void);

void               open_get_panel                 (void);
void               destroy_get_panel              (void);
void               hide_get_panel                 (void);
void               reset_get_panel                (void);

void               open_monitor_panel             (void);
void               destroy_monitor_panel          (void);
void               hide_monitor_panel             (void);
void               reset_monitor_panel            (void);

#endif
/* EOF */

==> gnome-admin-0.27.tar.gz: gnome-admin-0.27/gxsnmp/app/snmp_host.h <==
/*
 * $Id: snmp_host.h,v 1.23 1998/08/14 16:11:35 gregm Exp $
 * GXSNMP -- An snmp management application
 * Copyright (C) 1998 Gregory McLean
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc.,  59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
 *
 * Variables and functions specific to the host panel
 */
#ifndef __SNMP_HOST_H__
#define __SNMP_HOST_H__

#include <sys/types.h>
#include <time.h>
#include <gtk/gtk.h>
#include <netdb.h>
#include <netinet/in.h>
#include "net.h"

/* 
 * For the add host dialog 
 */
typedef struct _host_panel {
  GtkWidget 	*window;	    /* the window */
  GtkWidget     *buttons[2];        /* The buttons */
  GtkWidget     *entries[8];        /* The text entry widgets */
  GtkWidget     *s_widgets[2];      /* Server page widgets */
} host_panel;

/*
 * Used for both the set and get panels.
 */
typedef struct _set_panel {
  GtkWidget     *window;
  GtkWidget     *entries[3];
  GtkWidget     *buttons[3];
} set_panel;

#define HOST_OK_BUTTON   0
#define HOST_CAN_BUTTON  1

#define HOST_E_NAME   0
#define HOST_E_DISP   1
#define HOST_E_PORT   2
#define HOST_E_RCOM   3
#define HOST_E_WCOM   4
#define HOST_E_VERS   5
#define HOST_E_RETR   6
#define HOST_E_TIME   7

#define HOST_S_POLL   0
#define HOST_S_SERV   1

#define SET_QUERY_BUTTON  0
#define SET_CLEAR_BUTTON  1
#define SET_CLOSE_BUTTON  2

#define SET_MIB_ENTRY     0
#define SET_MIB_HOST      1
#define SET_MIB_RESULT    2

typedef struct __edit_host {
  GtkWidget     *window;
  GtkWidget     *widget[8];
} edit_host;


/*
 * Defines for the following host list
 */
#define HOST_STATE_UNKNOWN   -1
#define HOST_STATE_UP        0x01
#define HOST_STATE_DOWN      0x02

/*
 * Simple map location cordinates.
 */
typedef struct _map_location {
  int           x;
  int           y;
  int           width;
  int           height;
} location;

/*
 * Interface list for a given node.
 */
typedef struct _inf_list {
  struct in_addr    if_addr;      /* Ip address for this interface */
  struct in_addr    if_net;       /* Network # that this interface sits on */
  struct in_addr    if_mask;      /* The netmask for this interface */ 
  time_t            if_lastsnmp;  /* last time we did snmp on this interface */
  time_t            if_lastactive; /* Last time of any activity on this int */
  time_t            if_uptime;     /* Interface uptime (snmp derived) */
  time_t            if_lastup;     /* last update of the interface was */
  int               if_flags;      /* Up down disabled etc.. */
  int               if_speed;      /* Speed of this interface */
  char              if_index;      /* Index in the mib for this interface */
  struct _hosts     *if_host;      /* the host entry for this interface */
} inf_list;

/* 
 * The hosts structure
 */

typedef struct _hosts {
  char          *hl_disp;       /* what we should display on the map */
  GSList        *hl_if;         /* Interface list for this host*/
  gulong        root[SNMP_SIZE_OBJECTID];
  int           root_length;
  gulong        name[SNMP_SIZE_OBJECTID];
  int           name_length;
  u_long        hl_lastpong;    /* last response from a ping */
  int           hl_flags;       /* Flags for this host */
  int           hl_state;       /* The state of this host UP/Down etc.. */
  host_snmp     hl_snmp;        /* the snmp info associated with this host */
  GList         *monitor_list;  /* A list of mibs to monitor for this host */
  GtkWidget     *widget;        /* the widget that displays this host */
  GtkWidget     *listwidget;    /* the widget on the host list for this host */
  GnomeCanvasGroup *hl_mgroup;	/* The group for this host on the map */
  GnomeCanvasGroup *hl_ngroup;  /* The network group that this is connected to */
  GnomeCanvasItem  *hl_mconnection; /* The connect to the network */
  net_entry     *hl_network;    /* network we are connected to */
  location      hl_location;    /* Where to put this host on the map */
  u_long        hl_lastsnmpif;
  time_t        hl_lastsnmp;
  int           snmp_running;   /* do we have a request running? */
  int           rowid;          /* SQL row ID */
} hosts;

#define DEFAULT_COMMUNITY	"public"           /* read */
#define DEFAULT_WCOMMUNITY      "private"          /* write */
#define DEFAULT_PORT		"161"
/* 1 - 300 range */
#define DEFAULT_TIMEOUT		"30"
/* 1 - 32 range */
#define DEFAULT_RETRIES		"3"

/*
 * SQL stuff
 */
#define DEFAULT_DATABASE        "gxsnmp"


/*
 * Global functions defined by this module
 */
void add_host                   (hosts *entry);
/*
 * Exported standard panel functions
 */
void               open_add_host_panel            (void);
void               hide_add_host_panel            (void);
void               destroy_add_host_panel         (void);
void               reset_add_host_panel           (void);

void               open_edit_panel                (void);
void               hide_edit_panel                (void);
void               destroy_edit_panel             (void);
void               reset_edit_panel               (void);

void               open_set_panel                 (void);
void               destroy_set_panel              (void);
void               hide_set_panel                 (void);
void               reset_set_panel                (void);

void               open_get_panel                 (void);
void               destroy_get_panel              (void);
void               hide_get_panel                 (void);
void               reset_get_panel                (void);

void               open_monitor_panel             (void);
void               destroy_monitor_panel          (void);
void               hide_monitor_panel             (void);
void               reset_monitor_panel            (void);

#endif
/* EOF */
